cdn-definitions
===============

Data definitions for Red Hat's content delivery network.

![Build Status](https://github.com/release-engineering/cdn-definitions/actions/workflows/tests.yml/badge.svg)
[![codecov](https://codecov.io/gh/release-engineering/cdn-definitions/branch/master/graph/badge.svg?token=UFA82N1J4J)](https://codecov.io/gh/release-engineering/cdn-definitions)

- [Source](https://github.com/release-engineering/cdn-definitions)
- [Documentation](https://release-engineering.github.io/cdn-definitions/)
- [PyPI](https://pypi.org/project/cdn-definitions)

This project assists with the maintenance of a dataset influencing certain behaviors
of Red Hat's CDN, such as aliases between paths.

See the
[User Guide](https://release-engineering.github.io/cdn-definitions/userguide.html#) for more information
if you are interested in consuming this data.

License
-------

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
